The [ZX-calculus](http://zxcalculus.com) gives us a handy way to represent and work with quantum computations. ZXLive is an interactive tool for working with ZX. Draw graphs or load circuits and apply ZX rules. Intended for experimenting, building proofs, helping to write papers, showing off, or simply learning about ZX and quantum computing. It is powered by the [pyzx](https://github.com/Quantomatic/pyzx) open source library under the hood.

This project is in a pretty early stage, with lots more to come. Have a look at the [Issue Tracker](https://github.com/Quantomatic/zxlive/issues) to see what's in the pipeline.


## Instructions

To install from source, you need Python >= 3.9 and pip. If you have those, just run:

    git clone https://github.com/Quantomatic/zxlive.git
    cd zxlive
    pip install .

Then, you can run ZXLive by typing `python3 -m zxlive`.

